#!/bin/bash
# 20150805 install_LiveDVD.sh linux.gnu@yandex.ru
# Distributed under the terms of the GNU General Public License v3.

# Initials params
dev='/dev/sdb'
#type='hdd'		# min 80G
type='usb-hdd'		# min 32G
timezone='Asia/Krasnoyarsk'

# Count disk spase.
ram=`grep 'MemTotal:' /proc/meminfo |awk '{print $2}'`
if (( $ram < 512 ))
  then
    swap=1024
  else
    (( swap=2*$ram/1000 ))
fi
boot_size=128
dev_size=`parted -l $dev 2>/dev/null |grep /dev/sda |awk '{print $3}' |awk -FGB '{print $1}'`
(( dev_size=$dev_size/1000 ))
if (( $dev_size < 25000 )) && [ "$type" == 'usb-hdd' ]
  then
    echo "To small USB flash. Exiting!"
    exit 1
elif (( $dev_size < 70000 )) && [ "$type" == 'hdd' ]
  then
    echo "To small disk. Exiting!"
    exit 1
fi

# Partitioning disk
parted --align=opt -s ${dev} mklabel msdos
parted --align=opt -s ${dev} "unit MB
mkpart primary ext2 1 ${boot_size}"
parted --align=opt -s ${dev} set 1 boot on
parted --align=opt -s ${dev} "unit MB
mkpart primary 128 ${dev_size}"

if [ "$type" == 'usb-hdd' ]
  then
    # Create logical partitions
    pvcreate ${dev}2 1>/dev/null 2>&1
    vgcreate luwrain ${dev}2 1>/dev/null 2>&1
    lvcreate -L 2G -n tmp luwrain 1>/dev/null 2>&1
    lvcreate -L 12G -n usr luwrain 1>/dev/null 2>&1
    lvcreate -L 2G -n root luwrain 1>/dev/null 2>&1
    lvcreate -L 6G -n var luwrain 1>/dev/null 2>&1
    lvcreate -l 100%FREE -n home luwrain 1>/dev/null 2>&1
  else
    # Create logical partitions
    pvcreate ${dev}2 1>/dev/null 2>&1
    vgcreate luwrain ${dev}2 1>/dev/null 2>&1
    lvcreate -L ${swap}M -n swap luwrain 1>/dev/null 2>&1
    lvcreate -L 8G -n tmp luwrain 1>/dev/null 2>&1
    lvcreate -L 16G -n usr luwrain 1>/dev/null 2>&1
    lvcreate -L 2G -n root luwrain 1>/dev/null 2>&1
    lvcreate -L 16G -n var luwrain 1>/dev/null 2>&1
    lvcreate -L 16G -n portage luwrain 1>/dev/null 2>&1
    lvcreate -l 100%FREE -n home luwrain 1>/dev/null 2>&1
fi


# For hardened systems only
if [ `uname -r |grep hardened` != '' ]
  then
    echo 0 > /proc/sys/kernel/grsecurity/tpe
    for i in `ls /proc/sys/kernel/grsecurity/chroot_*`; do echo "0" > $i 2>/dev/null; done
fi

cl-install --uuid ON --type ${type} --mbr ${dev} -d /dev/mapper/luwrain-root:/:ext4:on -d ${dev}1:/boot:ext2:on -d /dev/mapper/luwrain-usr:/usr:ext4:on -d /dev/mapper/luwrain-home:/home:ext4:on -d /dev/mapper/luwrain-tmp:/tmp:ext4:on -d /dev/mapper/luwrain-var:/var:ext4:on --netconf openrc --dns 77.88.8.88,77.88.8.2 --ntp ntp.ix.ru -u root -u guest --crypt-home OFF --scheduler cfq --video radeon --composite -l ru_RU --timezone ${timezone} -s CLD --march x86_64 --iso /home/ftp/ISO/cld-14.16.2-x86_64.iso --autocheck ON --clean-pkg ON --update-other ON

# For hardened systems only
if [ `uname -r |grep hardened` != '' ]
  then
    echo 1 > /proc/sys/kernel/grsecurity/tpe
    for i in `ls /proc/sys/kernel/grsecurity/chroot_*`; do echo "1" > $i 2>/dev/null; done
fi

exit 0
